@@ -4,7 +4,7 @@
 # Licensed under the terms of the MIT License
 # ----------------------------------------------------------------------------
 
-from QScreenCast.QScreenCast import *
+from QScreenCast.QScreenCast import ScreenCastToolButton
 
 __version__ = "0.0.0"
-__version__='0.1.24'
+__version__='0.1.26'
